@@ -7,7 +7,7 @@
  * This exemption does not extend to derived works not owned by
  * the Transmission project.
  * 
- * $Id: details.c 5321 2008-03-21 14:23:56Z charles $
+ * $Id: details.c 5492 2008-04-02 23:18:46Z charles $
  */
 
 #include <stddef.h>
@@ -1139,7 +1139,7 @@ refresh_time_lb( GtkWidget * l, time_t t )
     if( !t )
         gtk_label_set_text( GTK_LABEL( l ), never );
     else {
-        char * str = rfc822date( t * 1000 );
+        char * str = rfc822date( (guint64)t * 1000 );
         gtk_label_set_text( GTK_LABEL( l ), str );
         g_free( str );
     }
