@@ -2,22 +2,23 @@ const char * fallback_ui_file =
 "<ui>\n"
 "  <menubar name='main-window-menu'>\n"
 "    <menu action='torrent-menu'>\n"
-"      <menuitem action='add-torrent'/>\n"
-"      <menuitem action='create-torrent'/>\n"
+"      <menuitem action='open-torrent-menu'/>\n"
+"      <menuitem action='new-torrent'/>\n"
 "      <separator/>\n"
 "      <menuitem action='start-torrent'/>\n"
 "      <menuitem action='update-tracker'/>\n"
 "      <menuitem action='pause-torrent'/>\n"
 "      <menuitem action='verify-torrent'/>\n"
-"      <menuitem action='remove-torrent'/>\n"
 "      <menuitem action='show-torrent-details'/>\n"
+"      <menuitem action='remove-torrent'/>\n"
+"      <menuitem action='delete-torrent'/>\n"
 "      <separator/>\n"
 "      <menuitem action='close'/>\n"
 "      <menuitem action='quit'/>\n"
 "    </menu>\n"
 "    <menu action='edit-menu'>\n"
 "      <menuitem action='select-all'/>\n"
-"      <menuitem action='unselect-all'/>\n"
+"      <menuitem action='deselect-all'/>\n"
 "      <separator/>\n"
 "      <menuitem action='edit-preferences'/>\n"
 "    </menu>\n"
@@ -25,8 +26,8 @@ const char * fallback_ui_file =
 "      <menuitem action='minimal-view'/>\n"
 "      <separator/>\n"
 "      <menuitem action='show-toolbar'/>\n"
-"      <menuitem action='show-filter-bar'/>\n"
-"      <menuitem action='show-status-bar'/>\n"
+"      <menuitem action='show-filterbar'/>\n"
+"      <menuitem action='show-statusbar'/>\n"
 "      <separator/>\n"
 "      <menuitem action='sort-by-activity'/>\n"
 "      <menuitem action='sort-by-name'/>\n"
@@ -45,7 +46,7 @@ const char * fallback_ui_file =
 "  </menubar>\n"
 "\n"
 "  <toolbar name='main-window-toolbar'>\n"
-"    <toolitem action='add-torrent'/>\n"
+"    <toolitem action='open-torrent-toolbar'/>\n"
 "    <toolitem action='start-torrent'/>\n"
 "    <toolitem action='pause-torrent'/>\n"
 "    <toolitem action='remove-torrent'/>\n"
@@ -62,10 +63,11 @@ const char * fallback_ui_file =
 "    <menuitem action='update-tracker'/>\n"
 "    <separator/>\n"
 "    <menuitem action='remove-torrent'/>\n"
+"    <menuitem action='delete-torrent'/>\n"
 "  </popup>\n"
 "\n"
 "  <popup name='icon-popup'>\n"
-"    <menuitem action='add-torrent'/>\n"
+"    <menuitem action='open-torrent-menu'/>\n"
 "    <separator/>\n"
 "    <menuitem action='toggle-main-window'/>\n"
 "    <menuitem action='toggle-message-log'/>\n"
@@ -74,13 +76,5 @@ const char * fallback_ui_file =
 "    <menuitem action='quit'/>\n"
 "  </popup>\n"
 "\n"
-"  <popup name='file-popup'>\n"
-"    <menu action='priority-menu'>\n"
-"      <menuitem action='priority-high'/>\n"
-"      <menuitem action='priority-normal'/>\n"
-"      <menuitem action='priority-low'/>\n"
-"    </menu>\n"
-"  </popup>\n"
-"\n"
 "</ui>";
 
