@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: net.c 4772 2008-01-21 01:51:31Z charles $
+ * $Id: net.c 5290 2008-03-18 19:14:21Z charles $
  *
  * Copyright (c) 2005-2008 Transmission authors and contributors
  *
@@ -92,8 +92,8 @@ makeSocketNonBlocking( int fd )
         if( evutil_make_socket_nonblocking( fd ) )
 #endif
         {
-            tr_err( "Couldn't set socket to non-blocking mode (%s)",
-                    strerror( sockerrno ) );
+            tr_err( _( "Couldn't create socket: %s" ),
+                    tr_strerror( sockerrno ) );
             tr_netClose( fd );
             fd = -1;
         }
@@ -132,9 +132,9 @@ tr_netOpen( const struct in_addr * addr, tr_port_t port,
 #endif
         && ( sockerrno != EINPROGRESS ) )
     {
-        tr_err( "Couldn't connect socket %d to %s, port %d (errno %d - %s)",
+        tr_err( _( "Couldn't connect socket %d to %s, port %d (errno %d - %s)" ),
                 s, inet_ntoa(*addr), port,
-                sockerrno, strerror(sockerrno) );
+                sockerrno, tr_strerror(sockerrno) );
         tr_netClose( s );
         s = -1;
     }
@@ -158,10 +158,7 @@ tr_netBind( int port, int type )
 #endif
 
     if( ( s = createSocket( type, 1 ) ) < 0 )
-    {
-        tr_err( "Couldn't create socket of type %d", type );
         return -1;
-    }
 
 #ifdef SO_REUSEADDR
     optval = 1;
@@ -176,12 +173,12 @@ tr_netBind( int port, int type )
     if( bind( s, (struct sockaddr *) &sock,
                sizeof( struct sockaddr_in ) ) )
     {
-        tr_err( "Couldn't bind port %d: %s", port, strerror(sockerrno) );
+        tr_err( _( "Couldn't bind port %d: %s" ), port, tr_strerror(sockerrno) );
         tr_netClose( s );
         return -1;
     }
      
-    tr_inf( "Bound socket %d to port %d", s, port );
+    tr_inf( _( "Bound socket %d to port %d" ), s, port );
     return s;
 }
 
