@@ -7,7 +7,7 @@
  * This exemption does not extend to derived works not owned by
  * the Transmission project.
  *
- * $Id: peer-mgr.c 4855 2008-01-28 21:05:48Z charles $
+ * $Id: peer-mgr.c 5204 2008-03-06 13:24:44Z charles $
  */
 
 #include <assert.h>
@@ -30,10 +30,8 @@
 #include "peer-mgr.h"
 #include "peer-mgr-private.h"
 #include "peer-msgs.h"
-#include "platform.h"
 #include "ptrarray.h"
 #include "ratecontrol.h"
-#include "shared.h"
 #include "torrent.h"
 #include "trcompat.h" /* strlcpy */
 #include "trevent.h"
@@ -199,12 +197,12 @@ myDebug( const char * file, int line, const Torrent * t, const char * fmt, ... )
 **/
 
 static void
-managerLock( struct tr_peerMgr * manager )
+managerLock( const struct tr_peerMgr * manager )
 {
     tr_globalLock( manager->handle );
 }
 static void
-managerUnlock( struct tr_peerMgr * manager )
+managerUnlock( const struct tr_peerMgr * manager )
 {
     tr_globalUnlock( manager->handle );
 }
@@ -547,6 +545,18 @@ getConnectedPeers( Torrent * t, int * setmeCount )
     return ret;
 }
 
+static int
+clientIsDownloadingFrom( const tr_peer * peer )
+{
+    return peer->clientIsInterested && !peer->clientIsChoked;
+}
+
+static int
+clientIsUploadingTo( const tr_peer * peer )
+{
+    return peer->peerIsInterested && !peer->peerIsChoked;
+}
+
 /***
 ****  Refill
 ***/
@@ -554,12 +564,10 @@ getConnectedPeers( Torrent * t, int * setmeCount )
 struct tr_refill_piece
 {
     tr_priority_t priority;
-    int percentDone;
+    int missingBlockCount;
     uint16_t random;
     uint32_t piece;
     uint32_t peerCount;
-    uint32_t fastAllowed;
-    uint32_t suggested;
 };
 
 static int
@@ -567,25 +575,14 @@ compareRefillPiece (const void * aIn, const void * bIn)
 {
     const struct tr_refill_piece * a = aIn;
     const struct tr_refill_piece * b = bIn;
+
+    /* fewer missing pieces goes first */
+    if( a->missingBlockCount != b->missingBlockCount )
+        return a->missingBlockCount < b->missingBlockCount ? -1 : 1;
     
     /* if one piece has a higher priority, it goes first */
     if( a->priority != b->priority )
         return a->priority > b->priority ? -1 : 1;
-
-    /* try to fill partial pieces */
-    if( a->percentDone != b->percentDone )
-        return a->percentDone > b->percentDone ? -1 : 1;
-    
-    /* if one *might be* fastallowed to us, get it first...
-     * I'm putting it on top so we prioritize those pieces at
-     * startup, then we'll have them, and we'll be denied access
-     * to them */
-    if (a->fastAllowed != b->fastAllowed)
-        return a->fastAllowed < b->fastAllowed ? -1 : 1;
-    
-    /* otherwise if one was suggested to us, get it */
-    if (a->suggested != b->suggested)
-        return a->suggested < b->suggested ? -1 : 1;
     
     /* otherwise if one has fewer peers, it goes first */
     if (a->peerCount != b->peerCount)
@@ -643,21 +640,13 @@ getPreferredPieces( Torrent     * t,
             setme->piece = piece;
             setme->priority = inf->pieces[piece].priority;
             setme->peerCount = 0;
-            setme->fastAllowed = 0;
             setme->random = tr_rand( UINT16_MAX );
-            setme->percentDone = (int)( 100.0 * tr_cpPercentBlocksInPiece( tor->completion, piece ) );
+            setme->missingBlockCount = tr_cpMissingBlocksInPiece( tor->completion, piece );
 
             for( k=0; k<peerCount; ++k ) {
                 const tr_peer * peer = peers[k];
                 if( peer->peerIsInterested && !peer->clientIsChoked && tr_bitfieldHas( peer->have, piece ) )
                     ++setme->peerCount;
-                /* The fast peer extension doesn't force a peer to actually HAVE a fast-allowed piece,
-                    but we're guaranteed to get the same pieces from different peers, 
-                    so we'll build a list and pray one actually have this one */
-                setme->fastAllowed = tr_peerMsgsIsPieceFastAllowed( peer->msgs, i );
-                /* Also, if someone SUGGESTed a piece to us, prioritize it over non-suggested others
-                 */
-                setme->suggested   = tr_peerMsgsIsPieceSuggested( peer->msgs, i );
             }
         }
 
@@ -761,6 +750,35 @@ getPreferredBlocks( Torrent * t, uint64_t * setmeCount )
     return ret;
 }
 
+static tr_peer**
+getPeersUploadingToClient( Torrent * t, int * setmeCount )
+{
+    int i;
+    int peerCount = 0;
+    int retCount = 0;
+    tr_peer ** peers = (tr_peer **) tr_ptrArrayPeek( t->peers, &peerCount );
+    tr_peer ** ret = tr_new( tr_peer*, peerCount );
+
+    /* get a list of peers we're downloading from */
+    for( i=0; i<peerCount; ++i )
+        if( clientIsDownloadingFrom( peers[i] ) )
+            ret[retCount++] = peers[i];
+
+    /* pick a different starting point each time so all peers
+     * get a chance at the first blocks in the queue */
+    if( retCount ) {
+        tr_peer ** tmp = tr_new( tr_peer*, retCount );
+        i = tr_rand( retCount );
+        memcpy( tmp, ret, sizeof(tr_peer*) * retCount );
+        memcpy( ret, tmp+i, sizeof(tr_peer*) * (retCount-i) );
+        memcpy( ret+(retCount-i), tmp, sizeof(tr_peer*) * i );
+        tr_free( tmp );
+    }
+
+    *setmeCount = retCount;
+    return ret;
+}
+
 static int
 refillPulse( void * vtorrent )
 {
@@ -781,15 +799,18 @@ refillPulse( void * vtorrent )
     tordbg( t, "Refilling Request Buffers..." );
 
     blocks = getPreferredBlocks( t, &blockCount );
-    peers = getConnectedPeers( t, &peerCount );
+    peers = getPeersUploadingToClient( t, &peerCount );
 
     for( i=0; peerCount && i<blockCount; ++i )
     {
+        int j;
+
         const uint64_t block = blocks[i];
         const uint32_t index = tr_torBlockPiece( tor, block );
         const uint32_t begin = (block * tor->blockSize) - (index * tor->info.pieceSize);
         const uint32_t length = tr_torBlockCountBytes( tor, (int)block );
-        int j;
+
+        assert( tr_torrentReqIsValid( tor, index, begin, length ) );
         assert( _tr_block( tor, index, begin ) == (int)block );
         assert( begin < (uint32_t)tr_torPieceCountBytes( tor, (int)index ) );
         assert( (begin + length) <= (uint32_t)tr_torPieceCountBytes( tor, (int)index ) );
@@ -922,12 +943,14 @@ msgsCallbackFunc( void * vpeer, void * vevent, void * vt )
             broadcastGotBlock( t, e->pieceIndex, e->offset, e->length );
             break;
 
-        case TR_PEERMSG_GOT_ASSERT_ERROR:
-            addStrike( t, peer );
-            peer->doPurge = 1;
-            break;
-
         case TR_PEERMSG_ERROR:
+            if( TR_ERROR_IS_IO( e->err ) ) {
+                t->tor->error = e->err;
+                strlcpy( t->tor->errorString, tr_errorString( e->err ), sizeof(t->tor->errorString) );
+                tr_torrentStop( t->tor );
+            } else if( e->err == TR_ERROR_ASSERT ) {
+                addStrike( t, peer );
+            }
             peer->doPurge = 1;
             break;
 
@@ -1192,7 +1215,7 @@ tr_peerMgrGetPeers( tr_peerMgr      * manager,
     tr_pex * pex;
     tr_pex * walk;
 
-    torrentLock( (Torrent*)t );
+    managerLock( manager );
 
     peers = (const tr_peer **) tr_ptrArrayPeek( t->peers, &peerCount );
     pex = walk = tr_new( tr_pex, peerCount );
@@ -1214,7 +1237,7 @@ tr_peerMgrGetPeers( tr_peerMgr      * manager,
     qsort( pex, peerCount, sizeof(tr_pex), tr_pexCompare );
     *setme_pex = pex;
 
-    torrentUnlock( (Torrent*)t );
+    managerUnlock( manager );
 
     return peerCount;
 }
@@ -1405,18 +1428,6 @@ tr_peerMgrHasConnections( const tr_peerMgr * manager,
     return ret;
 }
 
-static int
-clientIsDownloadingFrom( const tr_peer * peer )
-{
-    return peer->clientIsInterested && !peer->clientIsChoked;
-}
-
-static int
-clientIsUploadingTo( const tr_peer * peer )
-{
-    return peer->peerIsInterested && !peer->peerIsChoked;
-}
-
 void
 tr_peerMgrTorrentStats( const tr_peerMgr * manager,
                         const uint8_t    * torrentHash,
@@ -1455,11 +1466,11 @@ tr_peerMgrTorrentStats( const tr_peerMgr * manager,
 
         ++setmePeersFrom[atom->from];
 
-        if( clientIsUploadingTo( peer ) )
-            ++*setmePeersGettingFromUs;
-
         if( clientIsDownloadingFrom( peer ) )
             ++*setmePeersSendingToUs;
+
+        if( clientIsUploadingTo( peer ) )
+            ++*setmePeersGettingFromUs;
     }
 
     managerUnlock( (tr_peerMgr*)manager );
@@ -1484,21 +1495,39 @@ tr_peerMgrPeerStats( const tr_peerMgr  * manager,
 
     for( i=0; i<size; ++i )
     {
+        char * pch;
         const tr_peer * peer = peers[i];
         const struct peer_atom * atom = getExistingAtom( t, &peer->in_addr );
         tr_peer_stat * stat = ret + i;
 
         tr_netNtop( &peer->in_addr, stat->addr, sizeof(stat->addr) );
         strlcpy( stat->client, (peer->client ? peer->client : ""), sizeof(stat->client) );
-        stat->port             = peer->port;
-        stat->from             = atom->from;
-        stat->progress         = peer->progress;
-        stat->isEncrypted      = tr_peerIoIsEncrypted( peer->io ) ? 1 : 0;
-        stat->uploadToRate     = peer->rateToPeer;
-        stat->downloadFromRate = peer->rateToClient;
-        stat->isDownloading    = clientIsDownloadingFrom( peer );
-        stat->isUploading      = clientIsUploadingTo( peer );
-        stat->status           = peer->status;
+        stat->port               = peer->port;
+        stat->from               = atom->from;
+        stat->progress           = peer->progress;
+        stat->isEncrypted        = tr_peerIoIsEncrypted( peer->io ) ? 1 : 0;
+        stat->uploadToRate       = peer->rateToPeer;
+        stat->downloadFromRate   = peer->rateToClient;
+        stat->peerIsChoked       = peer->peerIsChoked;
+        stat->peerIsInterested   = peer->peerIsInterested;
+        stat->clientIsChoked     = peer->clientIsChoked;
+        stat->clientIsInterested = peer->clientIsInterested;
+        stat->isIncoming         = tr_peerIoIsIncoming( peer->io );
+        stat->isDownloadingFrom  = clientIsDownloadingFrom( peer );
+        stat->isUploadingTo      = clientIsUploadingTo( peer );
+
+        pch = stat->flagStr;
+        if( t->optimistic == peer ) *pch++ = 'O';
+        if( stat->isDownloadingFrom ) *pch++ = 'D';
+        else if( stat->clientIsInterested ) *pch++ = 'd';
+        if( stat->isUploadingTo ) *pch++ = 'U';
+        else if( stat->peerIsInterested ) *pch++ = 'u';
+        if( !stat->clientIsChoked && !stat->clientIsInterested ) *pch++ = 'K';
+        if( !stat->peerIsChoked && !stat->peerIsInterested ) *pch++ = '?';
+        if( stat->isEncrypted ) *pch++ = 'E';
+        if( stat->from == TR_PEER_FROM_PEX ) *pch++ = 'X';
+        if( stat->isIncoming ) *pch++ = 'I';
+        *pch = '\0';
     }
 
     *setmeCount = size;
