@@ -7,7 +7,7 @@
  * This exemption does not extend to derived works not owned by
  * the Transmission project.
  *
- * $Id: peer-msgs.h 4776 2008-01-21 02:07:55Z charles $
+ * $Id: peer-msgs.h 5199 2008-03-04 20:37:24Z charles $
  */
 
 #ifndef TR_PEER_MSGS_H
@@ -66,7 +66,6 @@ typedef enum
     TR_PEERMSG_PIECE_DATA,
     TR_PEERMSG_PEER_PROGRESS,
     TR_PEERMSG_ERROR,
-    TR_PEERMSG_GOT_ASSERT_ERROR,
     TR_PEERMSG_CANCEL,
     TR_PEERMSG_NEED_REQ
 }
@@ -79,6 +78,7 @@ typedef struct
     uint32_t offset;     /* for TR_PEERMSG_GOT_BLOCK */
     uint32_t length;     /* for TR_PEERMSG_GOT_BLOCK */
     float progress;      /* for TR_PEERMSG_PEER_PROGRESS */
+    tr_errno err;        /* for TR_PEERMSG_GOT_ERROR */
 }
 tr_peermsgs_event;
 
@@ -89,10 +89,4 @@ tr_publisher_tag  tr_peerMsgsSubscribe   ( tr_peermsgs       * peer,
 void              tr_peerMsgsUnsubscribe ( tr_peermsgs       * peer,
                                            tr_publisher_tag    tag );
 
-int               tr_peerMsgsIsPieceFastAllowed( const tr_peermsgs * peer,
-                                                 uint32_t            index );
-
-int               tr_peerMsgsIsPieceSuggested( const tr_peermsgs * peer,
-                                              uint32_t            index );
-
 #endif
