@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: platform.h 4404 2008-01-01 17:20:20Z charles $
+ * $Id: platform.h 5167 2008-02-28 19:06:23Z charles $
  *
  * Copyright (c) 2005-2008 Transmission authors and contributors
  *
@@ -24,6 +24,14 @@
 #ifndef TR_PLATFORM_H
 #define TR_PLATFORM_H
 
+#if defined(WIN32)
+#define TR_PATH_DELIMITER '\\'
+#define TR_PATH_DELIMITER_STR "\\"
+#else
+#define TR_PATH_DELIMITER '/'
+#define TR_PATH_DELIMITER_STR "/"
+#endif
+
 typedef struct tr_lock   tr_lock;
 typedef struct tr_thread tr_thread;
 
@@ -40,4 +48,14 @@ void         tr_lockLock       ( tr_lock * );
 void         tr_lockUnlock     ( tr_lock * );
 int          tr_lockHave       ( const tr_lock * );
 
+
+enum
+{
+  TR_LOCKFILE_SUCCESS,
+  TR_LOCKFILE_EOPEN,
+  TR_LOCKFILE_ELOCK
+};
+
+int          tr_lockfile       ( const char * filename );
+
 #endif
