@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: torrent.c 4885 2008-02-01 01:38:57Z charles $
+ * $Id: torrent.c 5313 2008-03-19 20:07:27Z charles $
  *
  * Copyright (c) 2005-2008 Transmission authors and contributors
  *
@@ -23,11 +23,7 @@
  *****************************************************************************/
 
 #include <assert.h>
-#include <stdio.h>
-#include <stdlib.h>
-#include <string.h>
-
-#include <sys/types.h>
+#include <string.h> /* memcmp */
 
 #include "transmission.h"
 #include "bencode.h"
@@ -35,19 +31,17 @@
 #include "crypto.h" /* for tr_sha1 */
 #include "fastresume.h"
 #include "fdlimit.h" /* tr_fdFileClose */
-#include "handshake.h"
-#include "inout.h"
 #include "metainfo.h"
-#include "net.h" /* tr_netNtop */
 #include "peer-mgr.h"
-#include "platform.h"
 #include "ratecontrol.h"
-#include "shared.h"
 #include "torrent.h"
 #include "tracker.h"
 #include "trcompat.h" /* for strlcpy */
 #include "trevent.h"
 #include "utils.h"
+#include "verify.h"
+
+#define MAX_BLOCK_SIZE (1024*16)
 
 /***
 ****
@@ -163,13 +157,13 @@ onTrackerResponse( void * tracker UNUSED, void * vevent, void * user_data )
             break;
 
         case TR_TRACKER_WARNING:
-            tr_err( "Tracker: Warning - %s", event->text );
+            tr_torerr( tor, _( "Tracker warning: \"%s\"" ), event->text );
             tor->error = TR_ERROR_TC_WARNING;
             strlcpy( tor->errorString, event->text, sizeof(tor->errorString) );
             break;
 
         case TR_TRACKER_ERROR:
-            tr_err( "Tracker: Error - %s", event->text );
+            tr_torerr( tor, _( "Tracker error: \"%s\"" ), event->text );
             tor->error = TR_ERROR_TC_ERROR;
             strlcpy( tor->errorString, event->text, sizeof(tor->errorString) );
             break;
@@ -297,7 +291,7 @@ torrentRealInit( tr_handle     * h,
      * (2) pieceSize must be a multiple of block size
      */
     tor->blockSize = info->pieceSize;
-    while( tor->blockSize > (1024*16) )
+    while( tor->blockSize > MAX_BLOCK_SIZE )
         tor->blockSize /= 2;
 
     tor->lastPieceSize = info->totalSize % info->pieceSize;
@@ -384,7 +378,7 @@ torrentRealInit( tr_handle     * h,
 
     /* maybe save our own copy of the metainfo */
     if( tr_ctorGetSave( ctor ) ) {
-        const benc_val_t * val;
+        const tr_benc * val;
         if( !tr_ctorGetMetainfo( ctor, &val ) ) {
             int len;
             uint8_t * text = (uint8_t*) tr_bencSave( val, &len );
@@ -420,7 +414,7 @@ tr_torrentParse( const tr_handle  * handle,
     int err = 0;
     int doFree;
     tr_info tmp;
-    const benc_val_t * metainfo;
+    const tr_benc * metainfo;
 
     if( setmeInfo == NULL )
         setmeInfo = &tmp;
@@ -585,6 +579,8 @@ tr_torrentStat( tr_torrent * tor )
     tc = tor->tracker;
     s->tracker = tr_trackerGetAddress( tor->tracker );
 
+    tr_trackerStat( tor->tracker, &s->tracker_stat );
+
     tr_peerMgrTorrentStats( tor->handle->peerMgr,
                             tor->info.hash,
                             &s->peersKnown,
@@ -593,14 +589,16 @@ tr_torrentStat( tr_torrent * tor )
                             &s->peersGettingFromUs,
                              s->peersFrom );
 
+    s->manualAnnounceTime = tr_trackerGetManualAnnounceTime( tor->tracker );
+
     s->percentComplete = tr_cpPercentComplete ( tor->completion );
 
     s->percentDone = tr_cpPercentDone( tor->completion );
     s->leftUntilDone = tr_cpLeftUntilDone( tor->completion );
 
-    if( tor->recheckState == TR_RECHECK_NOW )
+    if( tor->verifyState == TR_VERIFY_NOW )
         s->status = TR_STATUS_CHECK;
-    else if( tor->recheckState == TR_RECHECK_WAIT )
+    else if( tor->verifyState == TR_VERIFY_WAIT )
         s->status = TR_STATUS_CHECK_WAIT;
     else if( !tor->isRunning )
         s->status = TR_STATUS_STOPPED;
@@ -823,9 +821,12 @@ tr_torrentSetHasPiece( tr_torrent * tor, int pieceIndex, int has )
     tr_torrentUnlock( tor );
 }
 
-void tr_torrentRemoveSaved( tr_torrent * tor )
+void
+tr_torrentRemoveSaved( tr_torrent * tor )
 {
     tr_metainfoRemoveSaved( tor->info.hashString, tor->handle->tag );
+
+    tr_fastResumeRemove( tor );
 }
 
 /***
@@ -872,8 +873,7 @@ freeTorrent( tr_torrent * tor )
     assert( h->torrentCount >= 1 );
     h->torrentCount--;
 
-    tr_inf( "closing torrent %s... %d torrents left",
-            tor->info.name, h->torrentCount );
+    tr_torinf( tor, _( "Closing torrent; %d left" ), h->torrentCount );
 
     tr_metainfoFree( inf );
     tr_free( tor );
@@ -881,13 +881,35 @@ freeTorrent( tr_torrent * tor )
     tr_globalUnlock( h );
 }
 
-enum
+/**
+***  Start/Stop Callback
+**/
+
+static void
+fireActiveChange( tr_torrent * tor, int isRunning )
 {
-    AFTER_RECHECK_NONE,
-    AFTER_RECHECK_START,
-    AFTER_RECHECK_STOP,
-    AFTER_RECHECK_CLOSE
-};
+    assert( tor != NULL );
+
+    if( tor->active_func != NULL )
+        (tor->active_func)( tor, isRunning, tor->active_func_user_data );
+}
+
+void
+tr_torrentSetActiveCallback( tr_torrent             * tor,
+                             tr_torrent_active_func   func,
+                             void                   * user_data )
+{
+    assert( tor != NULL );
+    tor->active_func = func;
+    tor->active_func_user_data = user_data;
+}
+
+void
+tr_torrentClearActiveCallback( tr_torrent * torrent )
+{
+    tr_torrentSetActiveCallback( torrent, NULL, NULL );
+}
+
 
 static void
 checkAndStartImpl( void * vtor )
@@ -897,6 +919,7 @@ checkAndStartImpl( void * vtor )
     tr_globalLock( tor->handle );
 
     tor->isRunning  = 1;
+    fireActiveChange( tor, tor->isRunning );
     *tor->errorString = '\0';
     tr_torrentResetTransferStats( tor );
     tor->cpStatus = tr_cpGetStatus( tor->completion );
@@ -923,7 +946,7 @@ tr_torrentStart( tr_torrent * tor )
     {
         tr_fastResumeLoad( tor, TR_FR_PROGRESS, NULL );
         tor->isRunning = 1;
-        tr_ioRecheckAdd( tor, checkAndStartCB );
+        tr_verifyAdd( tor, checkAndStartCB );
     }
 
     tr_globalUnlock( tor->handle );
@@ -940,12 +963,13 @@ torrentRecheckDoneCB( tr_torrent * tor )
     tr_runInEventThread( tor->handle, torrentRecheckDoneImpl, tor );
 }
 void
-tr_torrentRecheck( tr_torrent * tor )
+tr_torrentVerify( tr_torrent * tor )
 {
     tr_globalLock( tor->handle );
 
+    tr_verifyRemove( tor );
     tr_torrentUncheck( tor );
-    tr_ioRecheckAdd( tor, torrentRecheckDoneCB );
+    tr_verifyAdd( tor, torrentRecheckDoneCB );
 
     tr_globalUnlock( tor->handle );
 }
@@ -957,9 +981,10 @@ stopTorrent( void * vtor )
     int i;
 
     tr_torrent * tor = vtor;
-    tr_ioRecheckRemove( tor );
+    tr_verifyRemove( tor );
     tr_peerMgrStopTorrent( tor->handle->peerMgr, tor->info.hash );
     tr_trackerStop( tor->tracker );
+    fireActiveChange( tor, 0 );
 
     for( i=0; i<tor->info.fileCount; ++i )
     {
@@ -975,7 +1000,8 @@ tr_torrentStop( tr_torrent * tor )
 {
     tr_globalLock( tor->handle );
 
-    saveFastResumeNow( tor );
+    if( !tor->isDeleting )
+        saveFastResumeNow( tor );
     tor->isRunning = 0;
     tr_runInEventThread( tor->handle, stopTorrent, tor );
 
@@ -989,6 +1015,8 @@ closeTorrent( void * vtor )
     saveFastResumeNow( tor );
     tor->isRunning = 0;
     stopTorrent( tor );
+    if( tor->isDeleting )
+        tr_torrentRemoveSaved( tor );
     freeTorrent( tor );
 }
 
@@ -997,19 +1025,43 @@ tr_torrentClose( tr_torrent * tor )
 {
     if( tor != NULL )
     {
-        tr_globalLock( tor->handle );
+        tr_handle * handle = tor->handle;
+        tr_globalLock( handle );
 
         tr_torrentClearStatusCallback( tor );
-        tr_runInEventThread( tor->handle, closeTorrent, tor );
+        tr_runInEventThread( handle, closeTorrent, tor );
 
-        tr_globalUnlock( tor->handle );
+        tr_globalUnlock( handle );
     }
 }
 
+void
+tr_torrentDelete( tr_torrent * tor )
+{
+    tor->isDeleting = 1;
+    tr_torrentClose( tor );
+}
+
+
 /**
 ***  Completeness
 **/
 
+static const char *
+getCompletionString( int type )
+{
+    switch( type )
+    {
+        /* Translators: this is a minor point that's safe to skip over, but FYI:
+           "Complete" and "Done" are specific, different terms in Transmission:
+           "Complete" means we've downloaded every file in the torrent.
+           "Done" means we're done downloading the files we wanted, but NOT all that exist */
+        case TR_CP_DONE:     return _( "Done" );
+        case TR_CP_COMPLETE: return _( "Complete" );
+        default:             return _( "Incomplete" );
+    }
+}
+
 static void
 fireStatusChange( tr_torrent * tor, cp_status_t status )
 {
@@ -1044,15 +1096,27 @@ tr_torrentRecheckCompleteness( tr_torrent * tor )
     tr_torrentLock( tor );
 
     cpStatus = tr_cpGetStatus( tor->completion );
-    if( cpStatus != tor->cpStatus ) {
+
+    if( cpStatus != tor->cpStatus )
+    {
+        const int recentChange = tor->downloadedCur != 0;
+
+        if( recentChange )
+        {
+            tr_torinf( tor, _( "State changed from \"%s\" to \"%s\"" ),
+                            getCompletionString( tor->cpStatus ),
+                            getCompletionString( cpStatus ) );
+        }
+
         tor->cpStatus = cpStatus;
         fireStatusChange( tor, cpStatus );
-        if( (cpStatus == TR_CP_COMPLETE) /* ...and if we're complete */
-            && tor->downloadedCur ) {        /* and it just happened */
-            tr_trackerCompleted( tor->tracker ); /* tell the tracker */
-        }
+
+        if( recentChange && ( cpStatus == TR_CP_COMPLETE ) )
+            tr_trackerCompleted( tor->tracker );
+
         saveFastResumeNow( tor );
     }
+
     tr_torrentUnlock( tor );
 }
 
@@ -1243,13 +1307,47 @@ tr_torrentGetMaxConnectedPeers( const tr_torrent  * tor )
 ****
 ***/
 
-int _tr_block( const tr_torrent * tor, int index, int begin )
+int
+_tr_block( const tr_torrent * tor, int index, int begin )
 {
     const tr_info * inf = &tor->info;
     return index * ( inf->pieceSize / tor->blockSize ) +
         begin / tor->blockSize;
 }
 
+int
+tr_torrentReqIsValid( const tr_torrent * tor,
+                      uint32_t           index,
+                      uint32_t           offset,
+                      uint32_t           length )
+{
+    int err = 0;
+
+    if( index >= (uint32_t) tor->info.pieceCount )
+        err = 1;
+    else if ( (int)offset >= tr_torPieceCountBytes( tor, (int)index ) )
+        err = 2;
+    else if( length > MAX_BLOCK_SIZE )
+        err = 3;
+    else if( tr_pieceOffset( tor, index, offset, length ) > tor->info.totalSize )
+        err = 4;
+
+    if( err )
+    {
+        fprintf( stderr, "(ticket #751) err is %d\n", err );
+        fprintf( stderr, "(ticket #751) req.index is %"PRIu32"\n", index );
+        fprintf( stderr, "(ticket #751) req.offset is %"PRIu32"\n", offset );
+        fprintf( stderr, "(ticket #751) req.length is %"PRIu32"\n", length );
+        fprintf( stderr, "(ticket #751) tor->info.totalSize is %"PRIu64"\n", tor->info.totalSize );
+        fprintf( stderr, "(ticket #751) tor->info.pieceCount is %d\n", tor->info.pieceCount );
+        fprintf( stderr, "(ticket #751) tr_torPieceCountBytes is %d\n", tr_torPieceCountBytes( tor, (int)index ) );
+        fprintf( stderr, "(ticket #751) tr_pieceOffset is %"PRIu64"\n", tr_pieceOffset( tor, index, offset, length ) );
+    }
+
+    return !err;
+}
+
+
 uint64_t
 tr_pieceOffset( const tr_torrent * tor, int index, int begin, int length )
 {
