@@ -7,7 +7,7 @@
  * This exemption does not extend to derived works not owned by
  * the Transmission project.
  *
- * $Id: tracker.c 4877 2008-01-31 03:09:24Z charles $
+ * $Id: tracker.c 5294 2008-03-18 19:38:39Z charles $
  */
 
 #include <assert.h>
@@ -28,6 +28,7 @@
 #include "shared.h"
 #include "torrent.h"
 #include "tracker.h"
+#include "trcompat.h" /* strlcpy */
 #include "trevent.h"
 #include "utils.h"
 
@@ -115,6 +116,12 @@ struct tr_tracker
     time_t reannounceAt;
     time_t scrapeAt;
 
+    time_t lastScrapeTime;
+    char lastScrapeResponse[512];
+
+    time_t lastAnnounceTime;
+    char lastAnnounceResponse[512];
+
     int randOffset;
 
     unsigned int isRunning     : 1;
@@ -155,7 +162,7 @@ myDebug( const char * file, int line, const tr_tracker * t, const char * fmt, ..
 ****
 ***/
 
-static tr_tracker_info *
+static const tr_tracker_info *
 getCurrentAddress( const tr_tracker * t )
 {
     assert( t->addresses != NULL );
@@ -255,7 +262,7 @@ publishNewPeers( tr_tracker * t, int count, uint8_t * peers )
     event.messageType = TR_TRACKER_PEERS;
     event.peerCount = count;
     event.peerCompact = peers;
-    tr_inf( "Torrent \"%s\" got %d new peers", t->name, count );
+    tr_ndbg( t->name, "Torrent got %d new peers", count );
     if( count )
         tr_publisherPublish( t->publisher, t, &event );
 }
@@ -274,24 +281,21 @@ onStoppedResponse( struct evhttp_request * req UNUSED, void * handle )
 }
 
 static int
-parseBencResponse( struct evhttp_request * req, benc_val_t * setme )
+parseBencResponse( struct evhttp_request * req, tr_benc * setme )
 {
     const unsigned char * body = EVBUFFER_DATA( req->input_buffer );
     const int bodylen = EVBUFFER_LENGTH( req->input_buffer );
     return tr_bencLoad( body, bodylen, setme, NULL );
 }
 
-static const char*
-updateAddresses( tr_tracker * t, const struct evhttp_request * req )
+static void
+updateAddresses( tr_tracker * t, const struct evhttp_request * req, int * tryAgain )
 {
-    const char * ret = NULL;
     int moveToNextAddress = FALSE;
 
-    if( !req )
+    if( !req ) /* tracker didn't respond */
     {
-        ret = "Tracker hasn't responded yet.  Retrying...";
-        tr_inf( ret );
-
+        tr_ninf( t->name, _( "Tracker hasn't responded yet.  Retrying..." ) );
         moveToNextAddress = TRUE;
     }
     else if( req->response_code == HTTP_OK )
@@ -336,16 +340,26 @@ updateAddresses( tr_tracker * t, const struct evhttp_request * req )
         moveToNextAddress = TRUE;
     }
 
-    if( moveToNextAddress )
-        if ( ++t->addressIndex >= t->addressCount )
-            t->addressIndex = 0;
+    *tryAgain = moveToNextAddress;
 
-    return ret;
+    if( moveToNextAddress )
+    {
+        if ( ++t->addressIndex >= t->addressCount ) /* we've tried them all */
+        {
+            *tryAgain = FALSE;
+            t->addressIndex = 0;
+        }
+        else
+        {
+            const tr_tracker_info * n = getCurrentAddress( t );
+            tr_ninf( t->name, _( "Trying next tracker \"%s:%d\"" ), n->address, n->port );
+        }
+    }
 }
 
 /* Convert to compact form */
 static uint8_t *
-parseOldPeers( benc_val_t * bePeers, int * setmePeerCount )
+parseOldPeers( tr_benc * bePeers, int * setmePeerCount )
 {
     int i;
     uint8_t *compact, *walk;
@@ -359,8 +373,8 @@ parseOldPeers( benc_val_t * bePeers, int * setmePeerCount )
     {
         struct in_addr addr;
         tr_port_t port;
-        benc_val_t * val;
-        benc_val_t * peer = &bePeers->val.l.vals[i];
+        tr_benc * val;
+        tr_benc * peer = &bePeers->val.l.vals[i];
 
         val = tr_bencDictFind( peer, "ip" );
         if( !val || val->type!=TYPE_STR || tr_netResolve(val->val.s.s, &addr) )
@@ -385,7 +399,7 @@ parseOldPeers( benc_val_t * bePeers, int * setmePeerCount )
 static void
 onTrackerResponse( struct evhttp_request * req, void * vhash )
 {
-    const char * warning;
+    int tryAgain;
     int responseCode;
     struct torrent_hash * torrent_hash = (struct torrent_hash*) vhash;
     tr_tracker * t = findTrackerFromHash( torrent_hash );
@@ -400,20 +414,23 @@ onTrackerResponse( struct evhttp_request * req, void * vhash )
             ( req && req->response_code_line ) ?  req->response_code_line
                                                : "(null)" );
 
-    tr_inf( "Torrent \"%s\" tracker response: %s",
-            t->name,
-            ( req ? req->response_code_line : "(null)") );
+    *t->lastAnnounceResponse = '\0';
+    if( req && req->response_code_line )
+        strlcpy( t->lastAnnounceResponse, req->response_code_line, sizeof( t->lastAnnounceResponse ) );
+
+    tr_ndbg( t->name, "tracker response: %s",
+             ( req ? req->response_code_line : "(null)") );
 
     if( req && ( req->response_code == HTTP_OK ) )
     {
-        benc_val_t benc;
+        tr_benc benc;
         const int bencLoaded = !parseBencResponse( req, &benc );
 
         publishErrorClear( t );
 
         if( bencLoaded && benc.type==TYPE_DICT )
         {
-            benc_val_t * tmp;
+            tr_benc * tmp;
 
             if(( tmp = tr_bencDictFind( &benc, "failure reason" ))) {
                 dbgmsg( t, "got failure message [%s]", tmp->val.s.s );
@@ -473,16 +490,18 @@ onTrackerResponse( struct evhttp_request * req, void * vhash )
             tr_bencFree( &benc );
     }
 
-    if (( warning = updateAddresses( t, req ) )) {
-        publishWarning( t, warning );
-        tr_err( warning );
-    }
+    updateAddresses( t, req, &tryAgain );
 
     /**
     ***
     **/
 
-    responseCode = req ? req->response_code : 503;
+    if( tryAgain )
+        responseCode = 300;
+    else if( req )
+        responseCode = req->response_code;
+    else
+        responseCode = 503;
 
     if( 200<=responseCode && responseCode<=299 )
     {
@@ -493,11 +512,12 @@ onTrackerResponse( struct evhttp_request * req, void * vhash )
     }
     else if( 300<=responseCode && responseCode<=399 )
     {
-        dbgmsg( t, "got a redirect; retrying immediately" );
+        const int interval = 5;
+        dbgmsg( t, "got a redirect. retrying in %d seconds", interval );
 
         /* it's a redirect... updateAddresses() has already
          * parsed the redirect, all that's left is to retry */
-        t->reannounceAt = time( NULL );
+        t->reannounceAt = time( NULL ) + interval;
         t->manualAnnounceAllowedAt = time( NULL ) + t->announceMinIntervalSec;
     }
     else if( 400<=responseCode && responseCode<=499 )
@@ -542,7 +562,7 @@ onTrackerResponse( struct evhttp_request * req, void * vhash )
 static void
 onScrapeResponse( struct evhttp_request * req, void * vhash )
 {
-    const char * warning;
+    int tryAgain;
     time_t nextScrapeSec = 60;
     struct torrent_hash * torrent_hash = (struct torrent_hash*) vhash;
     tr_tracker * t = findTrackerFromHash( torrent_hash );
@@ -555,14 +575,16 @@ onScrapeResponse( struct evhttp_request * req, void * vhash )
     if( t == NULL ) /* tracker's been closed... */
         return;
 
-    tr_inf( "Got scrape response for  '%s': %s",
-            t->name,
-            ( ( req && req->response_code_line ) ? req->response_code_line
-                                                 : "(null)") );
+    *t->lastScrapeResponse = '\0';
+    if( req && req->response_code_line )
+        strlcpy( t->lastScrapeResponse, req->response_code_line, sizeof( t->lastScrapeResponse ) );
+
+    tr_ndbg( t->name, "Got scrape response: \"%s\"",
+            ( ( req && req->response_code_line ) ? req->response_code_line : "(null)") );
 
     if( req && ( req->response_code == HTTP_OK ) )
     {
-        benc_val_t benc, *files;
+        tr_benc benc, *files;
         const int bencLoaded = !parseBencResponse( req, &benc );
 
         if( bencLoaded
@@ -574,8 +596,8 @@ onScrapeResponse( struct evhttp_request * req, void * vhash )
             {
                 const uint8_t* hash =
                         (const uint8_t*) files->val.l.vals[i].val.s.s;
-                benc_val_t *tmp, *flags;
-                benc_val_t *tordict = &files->val.l.vals[i+1];
+                tr_benc *tmp, *flags;
+                tr_benc *tordict = &files->val.l.vals[i+1];
                 if( memcmp( t->hash, hash, SHA_DIGEST_LENGTH ) )
                     continue;
 
@@ -594,9 +616,8 @@ onScrapeResponse( struct evhttp_request * req, void * vhash )
                     if(( tmp = tr_bencDictFind( flags, "min_request_interval")))
                         t->scrapeIntervalSec = tmp->val.i;
 
-                tr_dbg( "Torrent '%s' scrape successful."
-                        "  Rescraping in %d seconds",
-                        t->name, t->scrapeIntervalSec );
+                tr_ndbg( t->name, "Scrape successful.  Rescraping in %d seconds.",
+                         t->scrapeIntervalSec );
 
                 nextScrapeSec = t->scrapeIntervalSec;
             }
@@ -606,12 +627,12 @@ onScrapeResponse( struct evhttp_request * req, void * vhash )
             tr_bencFree( &benc );
     }
 
-    if (( warning = updateAddresses( t, req ) )) {
-        tr_err( warning );
-        publishWarning( t, warning );
-    }
+    updateAddresses( t, req, &tryAgain );
 
-    t->scrapeAt = time( NULL ) + t->randOffset + nextScrapeSec;
+    if( tryAgain ) 
+        t->scrapeAt = time( NULL );
+    else
+        t->scrapeAt = time( NULL ) + t->randOffset + nextScrapeSec;
 }
 
 /***
@@ -670,7 +691,7 @@ buildTrackerRequestURI( const tr_tracker  * t,
     struct evbuffer * buf = evbuffer_new( );
     char * ret;
 
-    char * ann = getCurrentAddress(t)->announce;
+    const char * ann = getCurrentAddress(t)->announce;
     
     evbuffer_add_printf( buf, "%s"
                               "%cinfo_hash=%s"
@@ -846,16 +867,32 @@ getConnection( tr_handle * handle, const char * address, int port )
 static void
 invokeRequest( tr_handle * handle, const struct tr_tracker_request * req )
 {
+    const time_t now = time( NULL );
     struct evhttp_connection * evcon = getConnection( handle, req->address, req->port );
     tr_tracker * t = findTracker( handle, req->torrent_hash );
     dbgmsg( t, "sending '%s' to tracker %s:%d, timeout is %d", req->uri, req->address, req->port, (int)req->timeout );
     evhttp_connection_set_timeout( evcon, req->timeout );
-    if( evhttp_make_request( evcon, req->req, EVHTTP_REQ_GET, req->uri ))
-        publishErrorMessageAndStop( t, "Tracker could not be reached." );
-    else {
-        ++handle->tracker->socketCount;
-        dbgmsg( t, "incremented socket count to %d", handle->tracker->socketCount );
+    ++handle->tracker->socketCount;
+
+    if( t != NULL )
+    {
+        if( req->reqtype == TR_REQ_SCRAPE )
+        {
+            t->lastScrapeTime = now;
+            t->scrapeAt = 0;
+        }
+        else
+        {
+            t->lastAnnounceTime = now;
+            t->reannounceAt = 0;
+            t->manualAnnounceAllowedAt = 0;
+        }
     }
+
+    if( evhttp_make_request( evcon, req->req, EVHTTP_REQ_GET, req->uri ))
+        (*req->req->cb)(req->req, req->req->cb_arg);
+    else
+        dbgmsg( t, "incremented socket count to %d", handle->tracker->socketCount );
 }
 
 static void
@@ -1108,11 +1145,17 @@ tr_trackerGetAddress( const tr_tracker   * t )
     return getCurrentAddress( t );
 }
 
+time_t
+tr_trackerGetManualAnnounceTime( const struct tr_tracker * t )
+{
+    return t->isRunning ? t->manualAnnounceAllowedAt : 0;
+}
+
 int
 tr_trackerCanManualAnnounce ( const tr_tracker * t)
 {
-    return t->isRunning
-            && ( time(NULL) >= t->manualAnnounceAllowedAt );
+    const time_t allow = tr_trackerGetManualAnnounceTime( t );
+    return allow && ( allow <= time( NULL ) );
 }
 
 void
@@ -1161,6 +1204,7 @@ tr_trackerStop( tr_tracker * t )
 {
     if( t->isRunning ) {
         t->isRunning = 0;
+        t->reannounceAt = t->manualAnnounceAllowedAt = 0;
         enqueueRequest( t->handle, t, TR_REQ_STOPPED );
     }
 }
@@ -1171,3 +1215,24 @@ tr_trackerChangeMyPort( tr_tracker * t )
     if( t->isRunning )
         tr_trackerReannounce( t );
 }
+
+void
+tr_trackerStat( const tr_tracker * t,
+                struct tr_tracker_stat * setme)
+{
+    assert( t != NULL );
+    assert( setme != NULL );
+
+    strlcpy( setme->scrapeResponse,
+             t->lastScrapeResponse,
+             sizeof( setme->scrapeResponse ) );
+    setme->lastScrapeTime = t->lastScrapeTime;
+    setme->nextScrapeTime = t->scrapeAt;
+
+    strlcpy( setme->announceResponse,
+             t->lastAnnounceResponse,
+             sizeof( setme->announceResponse ) );
+    setme->lastAnnounceTime = t->lastAnnounceTime;
+    setme->nextAnnounceTime = t->reannounceAt;
+    setme->nextManualAnnounceTime = t->manualAnnounceAllowedAt;
+}
