@@ -7,7 +7,7 @@
  * This exemption does not extend to derived works not owned by
  * the Transmission project.
  *
- * $Id: tracker.h 4404 2008-01-01 17:20:20Z charles $
+ * $Id: tracker.h 5086 2008-02-21 07:29:39Z charles $
  */
 
 #ifndef _TR_TRACKER_H_
@@ -70,6 +70,9 @@ void              tr_trackerUnsubscribe     ( struct tr_tracker * tracker,
 ****
 ***/
 
+void tr_trackerStat                         ( const tr_tracker       * tracker,
+                                              struct tr_tracker_stat * setme);
+
 void tr_trackerStart                        ( struct tr_tracker * );
 
 void tr_trackerCompleted                    ( struct tr_tracker * );
@@ -84,6 +87,8 @@ const tr_tracker_info * tr_trackerGetAddress( const struct tr_tracker * );
 
 int  tr_trackerCanManualAnnounce            ( const struct tr_tracker * );
 
+time_t tr_trackerGetManualAnnounceTime      ( const struct tr_tracker * );
+
 void tr_trackerGetCounts                    ( const struct tr_tracker *,
                                               int * setme_completedCount,
                                               int * setme_leecherCount,
