@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: transmission.c 5314 2008-03-19 20:34:35Z charles $
+ * $Id: transmission.c 5493 2008-04-02 23:43:54Z charles $
  *
  * Copyright (c) 2005-2008 Transmission authors and contributors
  *
@@ -342,17 +342,12 @@ tr_getGlobalPeerLimit( const tr_handle * handle UNUSED )
 void
 tr_torrentRates( tr_handle * h, float * toClient, float * toPeer )
 {
-    const tr_torrent * tor;
     tr_globalLock( h );
 
-    *toClient = *toPeer = 0.0;
-    for( tor = h->torrentList; tor; tor = tor->next )
-    {
-        float c, p;
-        tr_torrentGetRates( tor, &c, &p );
-        *toClient += c;
-        *toPeer += p;
-    }
+    if( toClient ) 
+        *toClient = tr_rcRate( h->download ); 
+    if( toPeer ) 
+        *toPeer = tr_rcRate( h->upload ); 
 
     tr_globalUnlock( h );
 }
