@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: FilePriorityCell.h 4423 2008-01-02 16:55:05Z livings124 $
+ * $Id: FilePriorityCell.h 4665 2008-01-15 03:33:44Z livings124 $
  * 
  * Copyright (c) 2007-2008 Transmission authors and contributors
  *
@@ -27,6 +27,12 @@
 
 @interface FilePriorityCell : NSSegmentedCell
 {
+    BOOL fHoverRow;
 }
 
+- (void) addTrackingAreasForView: (NSView *) controlView inRect: (NSRect) cellFrame withUserInfo: (NSDictionary *) userInfo
+            mouseLocation: (NSPoint) mouseLocation;
+- (void) mouseEntered: (NSEvent *) event;
+- (void) mouseExited: (NSEvent *) event;
+
 @end
