@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: InfoWindowController.m 5325 2008-03-21 21:07:31Z livings124 $
+ * $Id: InfoWindowController.m 5453 2008-03-30 04:42:06Z livings124 $
  *
  * Copyright (c) 2006-2008 Transmission authors and contributors
  *
@@ -1134,9 +1134,18 @@ typedef enum
     [fAnnounceNextField setStringValue: announceNext > 0 ? [NSString timeString: announceNext showSeconds: YES] : @""];
     
     //scrape fields
-    NSString * scrapeAddress = [[torrent trackerAddress] stringByAppendingString: [torrent trackerAddressScrape]];
-    [fScrapeAddressField setStringValue: scrapeAddress];
-    [fScrapeAddressField setToolTip: scrapeAddress];
+    NSString * scrapeAddressTail;
+    if ((scrapeAddressTail = [torrent trackerAddressScrape]))
+    {
+        NSString * scrapeAddress = [[torrent trackerAddress] stringByAppendingString: scrapeAddressTail];
+        [fScrapeAddressField setStringValue: scrapeAddress];
+        [fScrapeAddressField setToolTip: scrapeAddress];
+    }
+    else
+    {
+        [fScrapeAddressField setStringValue: @""];
+        [fScrapeAddressField setToolTip: @""];
+    }
     
     [fScrapeLastField setObjectValue: [torrent lastScrapeTime]];
     
