@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: Torrent.m 5325 2008-03-21 21:07:31Z livings124 $
+ * $Id: Torrent.m 5460 2008-03-31 18:39:44Z livings124 $
  *
  * Copyright (c) 2006-2008 Transmission authors and contributors
  *
@@ -739,7 +739,7 @@ void completenessChangeCallback(tr_torrent * torrent, cp_status_t status, void *
 
 - (NSString *) trackerAddressScrape
 {
-    return [NSString stringWithUTF8String: fStat->tracker->scrape];
+    return fStat->tracker->scrape ? [NSString stringWithUTF8String: fStat->tracker->scrape] : nil;
 }
 
 - (NSDate *) lastScrapeTime
@@ -968,7 +968,7 @@ void completenessChangeCallback(tr_torrent * torrent, cp_status_t status, void *
     
     if (![self allDownloaded])
     {
-        if ([fDefaults boolForKey: @"DisplayStatusProgressSelected"])
+        if ([self folder] && [fDefaults boolForKey: @"DisplayStatusProgressSelected"])
         {
             string = [NSString stringWithFormat: NSLocalizedString(@"%@ of %@ selected (%.2f%%)", "Torrent -> progress string"),
                             [NSString stringForFileSize: [self haveTotal]], [NSString stringForFileSize: [self totalSizeSelected]],
@@ -981,7 +981,7 @@ void completenessChangeCallback(tr_torrent * torrent, cp_status_t status, void *
     }
     else if (![self isComplete])
     {
-        if ([fDefaults boolForKey: @"DisplayStatusProgressSelected"])
+        if ([self folder] && [fDefaults boolForKey: @"DisplayStatusProgressSelected"])
             string = [NSString stringWithFormat: NSLocalizedString(@"%@ selected, uploaded %@ (Ratio: %@)",
                 "Torrent -> progress string"), [NSString stringForFileSize: [self haveTotal]],
                 [NSString stringForFileSize: [self uploadedTotal]], [NSString stringForRatio: [self ratio]]];
