@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: TorrentTableView.m 5282 2008-03-18 03:20:27Z livings124 $
+ * $Id: TorrentTableView.m 5460 2008-03-31 18:39:44Z livings124 $
  *
  * Copyright (c) 2005-2008 Transmission authors and contributors
  *
@@ -775,7 +775,8 @@
 - (BOOL) pointInProgressRect: (NSPoint) point
 {
     int row = [self rowAtPoint: point];
-    if (row < 0 || ![[self itemAtRow: row] isKindOfClass: [Torrent class]] || [fDefaults boolForKey: @"SmallView"])
+    if (row < 0 || ![[self itemAtRow: row] isKindOfClass: [Torrent class]] || [fDefaults boolForKey: @"SmallView"]
+        || ![[self itemAtRow: row] folder])
         return NO;
     
     TorrentCell * cell;
